@@ -9,7 +9,7 @@ import io
 from pathlib import Path
 from importlib.resources import read_text
 from configparser import ConfigParser, SectionProxy
-from typing import NamedTuple, Union, Dict
+from typing import NamedTuple, Union, Dict, List
 
 from rich.markdown import Markdown
 from rich.table import Table
@@ -47,6 +47,18 @@ class Location(NamedTuple):
     system_id_night: int
     '''SCC Lidar Configuration ID - Nightime'''
 
+    channel_id: List[int]
+    '''List of channel IDs (for SCC `channel_ID` variable)'''
+
+    background_low: List[int]
+    '''Value for the `Background_Low` variable'''
+
+    background_high: List[int]
+    '''Value for the `Background_High` variable'''
+
+    lr_input: List[int]
+    '''Value for the `lr_input` variable'''
+
     def print(self):
         '''
         Prints this location as a Table in the terminal
@@ -62,6 +74,10 @@ class Location(NamedTuple):
         table.add_row("lon", str(self.lon))
         table.add_row("system_id_day", str(self.system_id_day))
         table.add_row("system_id_night", str(self.system_id_night))
+        table.add_row("channel_id", ", ".join(self.channel_id))
+        table.add_row("background_low", ", ".join(self.background_low))
+        table.add_row("background_high", ", ".join(self.background_high))
+        table.add_row("lr_input", ", ".join(self.lr_input))
 
         console.print(table)
 
@@ -71,6 +87,15 @@ def location_from_section(name: str, section: SectionProxy) -> Location:
     Create a Location from a ConfigParser Section (SectionProxy)
     '''
 
+    channel_id = [int(x.strip())
+                  for x in section.get("channel_id").split(",")]
+    background_low = [int(x.strip())
+                      for x in section.get("background_low").split(",")]
+    background_high = [int(x.strip())
+                       for x in section.get("background_high").split(",")]
+    lr_input = [int(x.strip())
+                for x in section.get("lr_input").split(",")]
+
     return Location(
         name=name,
         profile_name=section["profile_name"],
@@ -79,7 +104,11 @@ def location_from_section(name: str, section: SectionProxy) -> Location:
         lon=section.getfloat("lon"),
         altitude=section.getfloat("altitude"),
         system_id_day=section.getint("system_id_day"),
-        system_id_night=section.getint("system_id_night")
+        system_id_night=section.getint("system_id_night"),
+        channel_id=channel_id,
+        background_low=background_low,
+        background_high=background_high,
+        lr_input=lr_input
     )
 
 
