@@ -20,10 +20,11 @@ class CreateSCC(Command):
 
     create-scc
         {input : Path to PollyXT files. Can be a single file or a directory of files.}
-        {--recursive : If set, the input directory will be searched recursively (i.e. in subdirectories). Ignored for files }
+        {--recursive : If set, the input directory will be searched recursively (i.e. in subdirectories). Ignored for files}
         {location : Where did the measurement take place for *all* input files }
         {output-path : Where to write output files (will create this directory if it doesn't exist)}
         {--interval= : Time interval (in minutes) to split each file. Default is one hour.}
+        {--start-hour= : When to start the first file in HH:MM format. The interval will be counted from here.}
         {--round : When set, output files will start on rounded down hours if possible (e.g. from 00:12 to 00:00, 01:42 to 01:00, etc)}
         {--no-radiosonde : If set, no radiosonde files will be created}
         {--no-calibration : Do not create calibration files}
@@ -69,7 +70,7 @@ class CreateSCC(Command):
             file_list = list(input_path.glob(pattern))
 
         if len(file_list) == 0:
-            self.line_error(f'<error>No netCDF files found in </error>{input_path}')
+            console.print(f'[error]No netCDF files found in[/error] {input_path}')
             return 1
 
         # Read config for radiosonde path
@@ -87,13 +88,13 @@ class CreateSCC(Command):
                 try:
                     profiles = radiosondes.wrf.read_wrf_daily_profile(config, location, day)
                 except FileNotFoundError as ex:
-                    self.line_error(
-                        f'<error>No radiosonde file found for </error>{location.name}<error> at </error>{day.isoformat()}')
-                    self.line_error('<error>Use the --no-radiosonde option to skip this.')
+                    console.print(
+                        f'[error]No radiosonde file found for [/error]{location.name}[error] at [/error]{day.isoformat()}')
+                    console.print('[error]Use the --no-radiosonde option to skip this.[/error]')
                     return 1
 
             converter = scc_netcdf.convert_pollyxt_file(
-                file, output_path, location, interval, should_round=should_round, calibration=(not skip_calibration), use_sounding=use_sounding)
+                file, output_path, location, interval, should_round=should_round, calibration=(not skip_calibration), use_sounding=use_sounding, start_hour=self.option("start-hour"))
             for id, path, timestamp in converter:
                 console.print(
                     f'[info]Created file with measurement ID[/info] {id} [info]at[/info] {str(path)}')
@@ -104,8 +105,8 @@ class CreateSCC(Command):
                     if len(p) > 0:
                         path = output_path / f'rs_{id[:-2]}.nc'
                         radiosondes.create_radiosonde_netcdf(p, location, path)
-                        self.line(f'<info>Created radiosonde file at</info> {path}')
+                        console.print(f'[info]Created radiosonde file at[/info] {path}')
                     else:
-                        self.line_error(f'<error>No radiosonde profile found for </error>{id}')
+                        console.print(f'[error]No radiosonde profile found for [/error]{id}')
 
-        self.line('\n<comment>Done!</comment>')
+        console.print('\n[info]Done![/info]')
