@@ -4,6 +4,7 @@ Routines for converting PollyXT files to SCC files
 
 from datetime import date, datetime, timedelta
 from pathlib import Path
+from pollyxt_pipelines.polly_to_scc.exceptions import StartingTimeOutsideFile
 from typing import Tuple
 from enum import Enum
 
@@ -130,20 +131,20 @@ def create_scc_netcdf(
     raw_data_start_time[:] = pf.measurement_time[:, 1] - pf.measurement_time[0, 1]
     raw_data_stop_time[:] = (pf.measurement_time[:, 1] - pf.measurement_time[0, 1]) + 30
     raw_lidar_data[:] = np.swapaxes(pf.raw_signal, 1, 2)
-    channel_id[:] = np.array([493, 500, 497, 499, 494, 496, 498, 495, 501, 941, 940, 502])
+    channel_id[:] = np.array(location.channel_id)
     id_timescale[:] = np.zeros(np.size(pf.raw_signal, axis=2))
     laser_pointing_angle[:] = int(pf.zenith_angle.item(0))
     laser_pointing_angle_of_profiles[:] = np.zeros(np.size(pf.raw_signal, axis=0))
     laser_shots[:] = pf.measurement_shots[:]
-    background_low[:] = np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    background_high[:] = np.array([249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249, 249])
+    background_low[:] = np.array(location.background_low)
+    background_high[:] = np.array(location.background_high)
     if use_sounding:
         molecular_calc[:] = 1
     else:
         molecular_calc[:] = 0
     pressure_at_lidar_station[:] = 1008
     temperature_at_lidar_station[:] = 20
-    lr_input[:] = np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1])
+    lr_input[:] = np.array(location.lr_input)
 
     # Close the netCDF file.
     nc.close()
@@ -299,7 +300,8 @@ def convert_pollyxt_file(
         interval: timedelta,
         use_sounding=True,
         should_round=False,
-        calibration=True):
+        calibration=True,
+        start_hour=None):
     '''
     Converts a PollyXT file into a bunch of SCC files. The input file will be split into intervals before being converted
     to the new format.
@@ -318,11 +320,22 @@ def convert_pollyxt_file(
         use_rounding: Whether the generated files will use radiosondes or not.
         should_round: If true, the interval starts will be rounded down. For example, from 01:02 to 01:00.
         calibration: Set to False to disable generation of calibration files.
+        start_hour: Optionally, set when the first file should start. The intervals will start from here.
     '''
 
     # Open input netCDF
     measurement_start, measurement_end = pollyxt.get_measurement_period(input_path)
 
+    # Move start time if requested
+    if start_hour is not None:
+        hour, minute = [int(x.strip()) for x in start_hour.split(':')]
+        start_hour = measurement_start.replace(hour=hour, minute=minute)
+
+        if start_hour < measurement_start or measurement_end < start_hour:
+            raise StartingTimeOutsideFile(measurement_start, measurement_end, start_hour)
+
+        measurement_start = start_hour
+
     # Create output files
     interval_start = measurement_start
     while interval_start < measurement_end:
