@@ -14,7 +14,7 @@ from netCDF4 import Dataset
 from pollyxt_pipelines.console import console
 from pollyxt_pipelines import locations
 from pollyxt_pipelines.scc_access import scc_session, SCC, SCC_Credentials, exceptions
-from pollyxt_pipelines.config import Config, config_paths
+from pollyxt_pipelines.config import Config, config_paths, print_login_error
 from pollyxt_pipelines.utils import bool_to_emoji, option_to_bool
 
 
@@ -104,13 +104,7 @@ class UploadFiles(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Upload files
@@ -120,12 +114,15 @@ class UploadFiles(Command):
             for file in track(files, description='Uploading files...', console=console):
                 # Read file to find radiosondes
                 nc = Dataset(file, 'r')
-                radiosonde_path = file.parent / nc.Sounding_File_Name
+                try:
+                    radiosonde_path = file.parent / nc.Sounding_File_Name
+                except AttributeError:
+                    radiosonde_path = None
                 dataset_id = nc.Measurement_ID
                 configuration_id = nc.NOAReACT_Configuration_ID
                 nc.close()
 
-                if not radiosonde_path.exists():
+                if radiosonde_path is not None and not radiosonde_path.exists():
                     console.print(
                         f'[error]Cannot find radiosonde file[/error] {radiosonde_path} [error] for measurement [/error] {file} [error]. Skipping file.[/error]')
                     continue
@@ -196,13 +193,7 @@ class DownloadFiles(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Download files for each ID
@@ -244,13 +235,7 @@ class DeleteSCC(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Login to SCC
@@ -302,13 +287,7 @@ class RerunSCC(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Login to SCC
@@ -385,13 +364,7 @@ class SearchSCC(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Login to SCC to make queries
@@ -515,13 +488,7 @@ class SearchDownloadSCC(Command):
         try:
             credentials = SCC_Credentials(config)
         except KeyError:
-            self.line('<error>Credentials not found in config</error>')
-            self.line('Use `pollyxt_pipelines config` to set the following variables:')
-            self.line('- http.username')
-            self.line('- http.password')
-            self.line('- auth.username')
-            self.line('- auth.password')
-            self.line('For example, `pollyxt_pipelines config http.username scc_user')
+            print_login_error()
             return 1
 
         # Login to SCC
